from vital_ai_vitalsigns.model.trait.PropertyTrait import PropertyTrait


class PropertyHasBirthday(PropertyTrait):
    namespace = "http://vital.ai/ontology/vital-core#"
    local_name = "hasBirthday"
